@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 import sys
 import os
 import random
@@ -36,7 +38,7 @@ def CreateRecordFile(interval):
         except:
             print "Failed to create RecordFolder!"
 
-    if(data.debug==1): PrintRecordData()
+    if(data.debug==True): PrintRecordData()
 
 
     #create file, write header
@@ -89,7 +91,7 @@ def CreateHeader():
     h=h+"\n"+"Time,   AccX, AccY, AccY:\n"
 
 #    print "Record header:\n"+h+"\n"
-    if(data.debug==1): print "##############################\nHeader:\n"+h+"\n##############################"
+    if(data.debug==True): print "##############################\nHeader:\n"+h+"\n##############################"
     return h
 
 
@@ -103,14 +105,14 @@ def WriteRecord():
     d=str(records.arrData[0][records.Index-1]) + ", " +  \
         str(records.arrData[1][records.Index-1]) + ", " +  \
         str(records.arrData[2][records.Index-1]) + ", " +  \
-        str(records.arrData[3][records.Index-1]) + ", " +  \
-        str(records.arrData[5][records.Index-1])
+        str(records.arrData[3][records.Index-1]) + ", "
+#        str(records.arrData[5][records.Index-1]) ##event note, not used anymore
 
     data.RecordFile.write(d+"\n")
-#    if(data.debug==1): print "Write to file:",d
+#    if(data.debug==True): print "Write to file:",d
 
     if(records.Index % 30 == 0):
-        if(data.debug==1): print "Flush data from IO buffer into file"
+        if(data.debug==True): print "Flush data from IO buffer into file"
         data.RecordFile.flush() #Every 30 indices (5 minutes in normal mode), write data from IO buffer into file
 
 
@@ -136,14 +138,14 @@ def LoadFileList():
     output = os.popen("cd "+str(data.RecordFolder)+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
     data.arrRecordFiles=output.split("\n")
     data.arrRecordFiles.pop()
-    if(data.debug==1): print data.arrRecordFiles
+    if(data.debug==True): print data.arrRecordFiles
     if(data.RecordFilename>""):
-        if(data.debug==1): print data.RecordFilename
+        if(data.debug==True): print data.RecordFilename
         data.arrRecordFilesIndex=0
         for i in range(len(data.arrRecordFiles)):
             if(data.RecordFilename==data.arrRecordFiles[i]): data.arrRecordFilesIndex=i
 
-    if(data.debug==1): print "LoadFileList,  Index:",  data.arrRecordFilesIndex
+    if(data.debug==True): print "LoadFileList,  Index:",  data.arrRecordFilesIndex
 
 
 
@@ -209,13 +211,13 @@ def LoadRecord():
             tmp=file.readline()
     #        print tmp
             if(tmp[:-1]!="No alarm set"):
-                if(data.debug==1): print "An alarm is set"
+                if(data.debug==True): print "An alarm is set"
 #                records.AlarmIsSet=True
                 tmp=string.replace(tmp[:-1], "Alarm: ",  "")
                 records.AlarmTime_tuple=time.strptime(tmp,  data.dateformat)
                 records.AlarmTime_seconds=Tuple2Seconds( records.AlarmTime_tuple)
             else:
-                if(data.debug==1): print "No alarm is set"
+                if(data.debug==True): print "No alarm is set"
 
            #process header line 4
             tmp=file.readline()
@@ -267,16 +269,16 @@ def LoadRecord():
             records.arrData[2][records.Index]=int(d[2]) #Y
             if(records.SWversion<1.8): #workaround for old files (versions <1.8 had only X and Y axis stored)
                 records.arrData[3][records.Index]=0 #Z
-                try:
-                    records.arrData[5][records.Index]=d[3] #Event
-                except:
-                    pass
+#                try:
+#                    records.arrData[5][records.Index]=d[3] #Event
+#                except:
+#                    pass
             else:
                 records.arrData[3][records.Index]=int(d[3]) #Z
-                try:
-                    records.arrData[5][records.Index]=d[4] #Event
-                except:
-                    pass
+#                try:
+#                    records.arrData[5][records.Index]=d[4] #Event
+#                except:
+#                    pass
 
             records.Index=records.Index+1
             if(records.Index==records.MaxArrayDataLen-1):
@@ -315,14 +317,14 @@ def LoadRecord():
     print "Loaded successful",  records.Index, "lines"
     if(records.AlarmIsSet==True):
         records.LastIndex=max(records.Index,  Tuple2Index(records.AlarmTimeWindowEnd_tuple)+5) #the very last index to be shown (incl. AlarmTimeWindowEnd
-        if(data.debug==1): print "But will show up to index",  records.LastIndex,  "as the AlarmTimeWindow ends there"
+        if(data.debug==True): print "But will show up to index",  records.LastIndex,  "as the AlarmTimeWindow ends there"
     else: records.LastIndex=records.Index
 
     records.status=_("Data successful loaded")
     print records.status
     records.statusID="OK"
 
-    if(data.debug==1): PrintRecordData(False)
+    if(data.debug==True): PrintRecordData(False)
     return 0 #all ok
 
 
@@ -344,7 +346,9 @@ def UpdateFileHeader():
     i=0
     for i in range(0,  records.Index):
         d=str(records.arrData[0][i]) + ", " + str(records.arrData[1][i]) + ", " +  str(records.arrData[2][i]) + \
-            ", " +  str(records.arrData[3][i]) + ", " +  str(records.arrData[5][i])
+            ", " +  str(records.arrData[3][i])
+#        d=str(records.arrData[0][i]) + ", " + str(records.arrData[1][i]) + ", " +  str(records.arrData[2][i]) + \
+#            ", " +  str(records.arrData[3][i]) + ", " +  str(records.arrData[5][i])
         file.write(d+"\n")
     file.close()
-    if(data.debug==1): print "Wrote",  i +1,  "records into file"
+    if(data.debug==True): print "Wrote",  i +1,  "records into file"
