@@ -1,4 +1,5 @@
-﻿###########################################################################
+﻿# -*- coding: utf-8 -*-
+###########################################################################
 ## All global variables in here are data either saved or loaded for/from a record file
 ###########################################################################
 
@@ -12,8 +13,8 @@ arrData=[[""]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*Max
     #2 Y movement
     #3 Z movement
     #4 Sum of X+Y+Z Derivation
-    #5 Event notes (String)
-    #6 SleepFiler applied
+    #5 Sum of X+Y+Z Derivation with noise reduction
+    #6 SleepFilter (Derivation multiplied with filter window)
 #field 2:
     # samples
 
